@@ -31,14 +31,14 @@ data Action = Action
   { on :: ActionOn
   , run :: ActionRun
   }
-  deriving stock Generic
+  deriving stock (Eq, Show, Generic)
   deriving anyclass (FromJSON, ToJSON)
 
 newAction :: ActionOn -> ActionRun -> Action
 newAction = Action
 
 data ActionOn = PostDeploy
-  deriving stock (Eq, Generic)
+  deriving stock (Eq, Show, Generic)
 
 instance FromJSON ActionOn where
   parseJSON = withText "ActionOn" $ \case
@@ -55,12 +55,12 @@ instance ToJSON ActionOn where
 data ActionRun
   = InvokeLambdaByStackOutput Text
   | InvokeLambdaByName Text
+  deriving stock (Eq, Show)
 
 instance FromJSON ActionRun where
-  parseJSON = withObject "ActionRun" $ \o -> asum
-    [ InvokeLambdaByStackOutput <$> o .: "InvokeLambdaByStackOutput"
-    , InvokeLambdaByStackOutput <$> o .: "InvokeLambdaByName"
-    ]
+  parseJSON = withObject "ActionRun" $ \o ->
+    (InvokeLambdaByStackOutput <$> o .: "InvokeLambdaByStackOutput")
+      <|> (InvokeLambdaByName <$> o .: "InvokeLambdaByName")
 
 instance ToJSON ActionRun where
   toJSON = object . \case
