@@ -1,6 +1,6 @@
 module Stackctl.Spec.Cat
   ( CatOptions(..)
-  , runCatOptions
+  , parseCatOptions
   , runCat
   ) where
 
@@ -21,7 +21,7 @@ import Stackctl.AWS
 import Stackctl.AWS.Scope
 import Stackctl.Colors
 import Stackctl.Config (HasConfig)
-import Stackctl.DirectoryOption (HasDirectoryOption(..))
+import Stackctl.DirectoryOption (HasDirectoryOption(..), unDirectoryOption)
 import Stackctl.FilterOption (HasFilterOption)
 import Stackctl.Spec.Discover
 import Stackctl.StackSpec
@@ -36,8 +36,8 @@ data CatOptions = CatOptions
 
 -- brittany-disable-next-binding
 
-runCatOptions :: Parser CatOptions
-runCatOptions = CatOptions
+parseCatOptions :: Parser CatOptions
+parseCatOptions = CatOptions
   <$> switch
     (  long "no-stacks"
     <> help "Only show templates/"
@@ -67,7 +67,7 @@ runCat
   => CatOptions
   -> m ()
 runCat CatOptions {..} = do
-  dir <- view directoryOptionL
+  dir <- unDirectoryOption <$> view directoryOptionL
   colors@Colors {..} <- getColorsStdout
   tree <- specTree <$> discoverSpecs
 
