@@ -1,7 +1,7 @@
 module Stackctl.Spec.Deploy
   ( DeployOptions(..)
   , DeployConfirmation(..)
-  , runDeployOptions
+  , parseDeployOptions
   , runDeploy
   ) where
 
@@ -23,10 +23,12 @@ import Stackctl.Prompt
 import Stackctl.Spec.Changes.Format
 import Stackctl.Spec.Discover
 import Stackctl.StackSpec
+import Stackctl.TagOption
 import UnliftIO.Directory (createDirectoryIfMissing)
 
 data DeployOptions = DeployOptions
   { sdoParameters :: [Parameter]
+  , sdoTags :: [Tag]
   , sdoSaveChangeSets :: Maybe FilePath
   , sdoDeployConfirmation :: DeployConfirmation
   , sdoClean :: Bool
@@ -34,9 +36,10 @@ data DeployOptions = DeployOptions
 
 -- brittany-disable-next-binding
 
-runDeployOptions :: Parser DeployOptions
-runDeployOptions = DeployOptions
+parseDeployOptions :: Parser DeployOptions
+parseDeployOptions = DeployOptions
   <$> many parameterOption
+  <*> many tagOption
   <*> optional (strOption
     (  long "save-change-sets"
     <> metavar "DIRECTORY"
@@ -74,7 +77,7 @@ runDeploy DeployOptions {..} = do
     withThreadContext ["stackName" .= stackSpecStackName spec] $ do
       handleRollbackComplete sdoDeployConfirmation $ stackSpecStackName spec
 
-      emChangeSet <- createChangeSet spec sdoParameters
+      emChangeSet <- createChangeSet spec sdoParameters sdoTags
 
       case emChangeSet of
         Left err -> do
