@@ -42,6 +42,9 @@ data StackSpec = StackSpec
   , ssSpecBody :: StackSpecYaml
   }
 
+stackSpecSpecRoot :: StackSpec -> FilePath
+stackSpecSpecRoot = ssSpecRoot
+
 stackSpecSpecPath :: StackSpec -> StackSpecPath
 stackSpecSpecPath = ssSpecPath
 
@@ -60,15 +63,20 @@ stackSpecDepends = fromMaybe [] . ssyDepends . ssSpecBody
 stackSpecActions :: StackSpec -> [Action]
 stackSpecActions = fromMaybe [] . ssyActions . ssSpecBody
 
--- | Normalized, relative path to the @[{root}/]stacks/@ file
+-- | Relative path @stacks/...@
 stackSpecStackFile :: StackSpec -> FilePath
-stackSpecStackFile StackSpec {..} =
-  FilePath.normalise $ ssSpecRoot </> stackSpecPathFilePath ssSpecPath
+stackSpecStackFile = stackSpecPathFilePath . ssSpecPath
 
--- | Normalized, relative path to the @[{root}/]templates/@ file
+-- | Relative path @templates/...@
 stackSpecTemplateFile :: StackSpec -> FilePath
-stackSpecTemplateFile StackSpec {..} =
-  FilePath.normalise $ ssSpecRoot </> "templates" </> ssyTemplate ssSpecBody
+stackSpecTemplateFile = ("templates" </>) . ssyTemplate . ssSpecBody
+
+stackSpecTemplate :: StackSpec -> StackTemplate
+stackSpecTemplate spec =
+  StackTemplate
+    $ FilePath.normalise
+    $ ssSpecRoot spec
+    </> stackSpecTemplateFile spec
 
 stackSpecParameters :: StackSpec -> [Parameter]
 stackSpecParameters =
@@ -127,19 +135,17 @@ writeTemplateBody path body = do
   dir = takeDirectory path
   ext = takeExtension path
 
-writeStackSpec
-  :: MonadUnliftIO m
-  => FilePath -- ^ Parent directory
-  -> StackSpec
-  -> TemplateBody
-  -> m ()
-writeStackSpec parent stackSpec@StackSpec {..} templateBody = do
+writeStackSpec :: MonadUnliftIO m => StackSpec -> TemplateBody -> m ()
+writeStackSpec stackSpec templateBody = do
   writeTemplateBody templatePath templateBody
   createDirectoryIfMissing True $ takeDirectory specPath
-  liftIO $ Yaml.encodeFile specPath ssSpecBody
+  liftIO $ Yaml.encodeFile specPath $ stackSpecSpecBody stackSpec
  where
-  templatePath = stackSpecTemplateFile stackSpec
-  specPath = parent </> stackSpecPathFilePath ssSpecPath
+  templatePath = unStackTemplate $ stackSpecTemplate stackSpec
+  specPath =
+    FilePath.normalise
+      $ stackSpecSpecRoot stackSpec
+      </> stackSpecStackFile stackSpec
 
 readStackSpec
   :: (MonadIO m, MonadReader env m, HasConfig env)
@@ -164,15 +170,16 @@ createChangeSet
      )
   => StackSpec
   -> [Parameter]
+  -> [Tag]
   -> m (Either Text (Maybe ChangeSet))
-createChangeSet spec parameters = awsCloudFormationCreateChangeSet
+createChangeSet spec parameters tags = awsCloudFormationCreateChangeSet
   (stackSpecStackName spec)
   (stackSpecStackDescription spec)
-  (StackTemplate $ stackSpecTemplateFile spec)
+  (stackSpecTemplate spec)
   (nubOrdOn (^. parameter_parameterKey) $ parameters <> stackSpecParameters spec
   )
   (stackSpecCapabilities spec)
-  (stackSpecTags spec)
+  (nubOrdOn (^. tag_key) $ tags <> stackSpecTags spec)
 
 sortStackSpecs :: [StackSpec] -> [StackSpec]
 sortStackSpecs = sortByDependencies stackSpecStackName stackSpecDepends
